@@ -281,6 +281,10 @@ class Base(Controller):
                 "help" : "Number of suggestions to return",
                 "action": "store",
                 "default": 5
+            }),
+            (['-m','--model'],{
+                "help": "which model to use",
+                "action": "store",
             })
         ]
     )
@@ -289,9 +293,16 @@ class Base(Controller):
         import pprint as pp
 
         if self.app.pargs.text=='ls':
-            pp.pprint(list_models())
+            # pp.pprint(list_models())
+            import pandas as pd
+            pd.set_option('display.max_rows', 500)
+            
+            
+            data = list_models()['data']
+            df = pd.DataFrame.from_dict(data)
+            print(df)
         else:
-            suggestions = get_cai_suggestions(self.app.pargs.text, self.app.pargs.n_suggestions)
+            suggestions = get_cai_suggestions(self.app.pargs.text, self.app.pargs.n_suggestions, self.app.pargs.model)
             pp.pprint(suggestions)
 
 
